gfe-relnote: deprecate gfe2_reloadable_flag_quic_enable_version_50

PiperOrigin-RevId: 284025291
Change-Id: I26591c4c77425a5d434a16d9a3456f217273240b
diff --git a/quic/core/quic_dispatcher_test.cc b/quic/core/quic_dispatcher_test.cc
index 896438a..0f78020 100644
--- a/quic/core/quic_dispatcher_test.cc
+++ b/quic/core/quic_dispatcher_test.cc
@@ -865,7 +865,6 @@
 
 TEST_F(QuicDispatcherTest, ProcessPacketWithInvalidShortInitialConnectionId) {
   // Enable a version that supports connection IDs of length different than 8.
-  SetQuicReloadableFlag(quic_enable_version_50, true);
   CreateTimeWaitListManager();
 
   QuicSocketAddress client_address(QuicIpAddress::Loopback4(), 1);
@@ -911,7 +910,6 @@
 TEST_F(QuicDispatcherTest, SupportedTransportVersionsChangeInFlight) {
   static_assert(QUIC_ARRAYSIZE(kSupportedTransportVersions) == 6u,
                 "Supported versions out of sync");
-  SetQuicReloadableFlag(quic_enable_version_50, true);
   SetQuicReloadableFlag(quic_enable_version_99, true);
 
   VerifyVersionNotSupported(QuicVersionReservedForNegotiation());
@@ -920,15 +918,15 @@
                                            QuicVersionMin().transport_version));
   VerifyVersionSupported(QuicVersionMax());
 
-  // Turn off version 50.
-  SetQuicReloadableFlag(quic_enable_version_50, false);
+  // Turn off version 99.
+  SetQuicReloadableFlag(quic_enable_version_99, false);
   VerifyVersionNotSupported(
-      ParsedQuicVersion(PROTOCOL_QUIC_CRYPTO, QUIC_VERSION_50));
+      ParsedQuicVersion(PROTOCOL_QUIC_CRYPTO, QUIC_VERSION_99));
 
-  // Turn on version 50.
-  SetQuicReloadableFlag(quic_enable_version_50, true);
+  // Turn on version 99.
+  SetQuicReloadableFlag(quic_enable_version_99, true);
   VerifyVersionSupported(
-      ParsedQuicVersion(PROTOCOL_QUIC_CRYPTO, QUIC_VERSION_50));
+      ParsedQuicVersion(PROTOCOL_QUIC_CRYPTO, QUIC_VERSION_99));
 }
 
 TEST_F(QuicDispatcherTest, RejectDeprecatedVersionsWithVersionNegotiation) {